﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.Generic;
using System.Collections.ObjectModel;

namespace IgDemos.Models
{
    public class NodeItem : DependencyObject
    {

        #region ParentId
        public int ParentId
        {
            get { return (int)GetValue(ParentIdProperty); }
            set { SetValue(ParentIdProperty, value); }
        }

        // Using a DependencyProperty as the backing store for ParentId.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty ParentIdProperty =
            DependencyProperty.Register("ParentId", typeof(int), typeof(NodeItem), new PropertyMetadata(0));
        #endregion

        public string Code { get; set; }


        #region Id
        public int Id
        {
            get { return (int)GetValue(IdProperty); }
            set { SetValue(IdProperty, value); }
        }

        // Using a DependencyProperty as the backing store for Id.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty IdProperty =
            DependencyProperty.Register("Id", typeof(int), typeof(NodeItem), new PropertyMetadata(0));
        #endregion


        #region DisplayName
        public string DisplayName
        {
            get { return (string)GetValue(DisplayNameProperty); }
            set { SetValue(DisplayNameProperty, value); }
        }

        // Using a DependencyProperty as the backing store for DisplayName.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty DisplayNameProperty =
            DependencyProperty.Register("DisplayName", typeof(string), typeof(NodeItem), new PropertyMetadata(""));
        #endregion

        public ObservableCollection<NodeItem> MyChildren { get; set; }
        
        public NodeItem()
        {
        }

        public static ObservableCollection<NodeItem> GetItems()
        {
            ObservableCollection<NodeItem> items = new ObservableCollection<NodeItem>();
            for (int i = 1; i <= 10; i++)
            {
                NodeItem item = new NodeItem();
                item.Id = i;
                item.DisplayName = string.Format("Node {0}", i);
                item.ParentId = 0;
                item.MyChildren = new ObservableCollection<NodeItem>();
                for (int j = 1; j <= 5; j++)
                {
                    NodeItem cItem = new NodeItem();
                    cItem.Id = (10 + i + j)*j;
                    cItem.ParentId = item.Id;
                    cItem.DisplayName = string.Format("Child {0}", cItem.Id);
                    cItem.MyChildren = new ObservableCollection<NodeItem>();
                    for (int k = 1; k <= 3; k++)
                    {
                        NodeItem ccItem = new NodeItem();
                        ccItem.Id = (10 + i + j + k)*10;
                        ccItem.ParentId = cItem.Id;
                        ccItem.DisplayName = string.Format("Sub Child {0}", ccItem.Id);
                        cItem.MyChildren.Add(ccItem);
                    }
                    item.MyChildren.Add(cItem);
                }
                items.Add(item);
            }
            return items;
        }
    }
}
